/**
 * This sketch demonstrates how to use an AudioRecorder to record audio to disk
 * and then immediately play it back by creating a new FilePlayer using the AudioRecordingStream
 * returned by the save method.
 * <p> 
 * To use this sketch you need to have something plugged into the line-in on your computer.<br/>
 * Press 'r' to toggle recording on and off and the press 's' to save to disk.<br/>
 * The recorded file will be placed in the main folder of the sketch.
 * <p>
 * For more information about Minim and additional features, visit http://code.compartmental.net/minim/
 */

import ddf.minim.*;
import ddf.minim.ugens.*;
import ddf.minim.analysis.*;

Minim minim;

// for recording
AudioInput in;
AudioRecorder recorder;
boolean recorded;

FFT fft;
// for playing back
AudioOutput out;
FilePlayer player;

void setup()
{
  size(1366, 768, P3D);

  minim = new Minim(this);

  // get a stereo line-in: sample buffer length of 2048
  // default sample rate is 44100, default bit depth is 16
  in = minim.getLineIn(Minim.STEREO, 2048);

  // create an AudioRecorder that will record from in to the filename specified.
  // the file will be located in the sketch's main folder.
  recorder = minim.createRecorder(in, "myrecording.wav");

  // get an output we can playback the recording on
  out = minim.getLineOut( Minim.STEREO );

  fft = new FFT( 2048, 44100 );


  textFont(createFont("Arial", 12));
}

void draw()
{
  background(0); 
  stroke(255);

  fft.forward( in.mix );

  // draw the waveforms
  // the values returned by left.get() and right.get() will be between -1 and 1,
  // so we need to scale them up to see the waveform
  //for(int i = 0; i < fft.specSize(); i++)
  //{
  // draw the line for frequency band i, scaling it up a bit so we can see it
  //  line( i, height, i, height - fft.getBand(i)*8 );
  //}

  //for(int i=0; i<20; i++)
  //{
  //   float x = 20+i*60;
  //   float y = height/2;
  //   float taille = 1+fft.getBand(i)*2;
  //   fill(200,133,133);
  //   noStroke();
  //   ellipse(x, y, taille, taille);
  //text(str(i),
  //   text(i, x, y-20);
  //}
  float col;
  float maxtaille =0;
  float x;
  float y;
  float taille;
  for (int i=0; i<4000; i++)
  {
    if (i<=200){
      x = 33+1300*(i)/200;
      y = height/4;
      taille = 30+fft.getFreq(i)*3;
      if(taille>maxtaille){
        maxtaille = taille;
      }
      col = 1-(taille / maxtaille);
      fill(0+(255*(i*col)/200), (255-(255*(i*col)/200)), (35+(255*(i*col)/200))/3);
      noStroke();
      ellipse(x, y, taille/8, taille/3);
      //text(str(i),
      if (i%10 ==0)
        text(i, x, y-35);

      switch (i)

      {

      case 33 : 
      case 65 : 
      case 131 : 


        text("Do", x, y+50);  

        break;

      case 37 : 
      case 73 : 
      case 147 :  


        text("Ré", x, y+50);

        break;   

      case 41 : 
      case 82 : 
      case 165 :  

        text("Mi", x, y+50); 

        break;    

      case 44 : 
      case 87 : 
      case 175 : 

        text("Fa", x, y+50);

        break; 

      case 49 : 
      case 98 : 
      case 196 : 

        text("Sol", x, y+50); 

        break; 

      case 55 :
      case 110 : 


        text("La", x, y+50); 

        break; 

      case 62 : 
      case 124 : 
     
        text("Si", x, y+50); 

        break;
      
    }
    }
    else if (i<=1000 && i>200) {

      x = 33+1300*(i-200)/800;
      y = height/2;
      taille = 10+fft.getFreq(i)/2;
      if(taille>maxtaille){
        maxtaille = taille;
      }
      col = 1-(taille / maxtaille);
      fill((255-((i*col)-200)/800), ((255*(i*(1-col)-200)/800)), ((255*((i*col)-200)/800))/3);
      noStroke();
      ellipse(x, y, taille/8, taille);
      //text(str(i),
      if (i%50 ==0)
        text(i, x, y-35);

      switch (i)

      {

      case 33 : 
      case 65 : 
      case 131 : 
      case 262 : 
      case 523 : 


        text("Do", x, y+50);  

        break;

      case 37 : 
      case 73 : 
      case 147 : 
      case 294 : 
      case 587 : 


        text("Ré", x, y+50);

        break;   

      case 41 : 
      case 82 : 
      case 165 : 
      case 330 : 
      case 659 : 

        text("Mi", x, y+50); 

        break;    

      case 44 : 
      case 87 : 
      case 175 : 
      case 349 : 
      case 699 :


        text("Fa", x, y+50);

        break; 

      case 49 : 
      case 98 : 
      case 196 : 
      case 392 : 
      case 784 : 

        text("Sol", x, y+50); 

        break; 

      case 55 :
      case 110 : 
      case 220 : 
      case 440 : 
      case 880 : 


        text("La", x, y+50); 

        break; 

      case 62 : 
      case 124 : 
      case 247 : 
      case 494 : 
      case 988 : 
     
        text("Si", x, y+50);

        break;
      }
    } else {
      x = 33+1300*(i-1000)/3000;
      y = 3*height/4;
      taille = 10+fft.getFreq(i)/2;
      if(taille>maxtaille){
        maxtaille = taille;
      }
      col = 1-(taille / maxtaille);
      fill((100+155*((i*col)-1000)/4000), (255-(255*((i*col)-1000)/4000))/2, (35+(255*((i*col)-1000)/4000))/1.5);
      noStroke();
      ellipse(x, y, taille/8, taille);
      //text(str(i),
      if (i%100 ==0)
        text(i, x, y-35);

      switch (i)

      {

      case 1047 : 
      case 2093 :

        text("Do", x, y+50);  

        break;

 
      case 1175 : 
      case 2349 :

        text("Ré", x, y+50);

        break;   

      
      case 1319 : 
      case 2637 :

        text("Mi", x, y+50); 

        break;    

      
      case 1397 : 
      case 2794 :

        text("Fa", x, y+50); 

        break; 

      
      case 1568 : 
      case 3136 :

        text("Sol", x,y+50); 

        break; 

      
      case 1760 : 
      case 3520 :

        text("La", x, y+50);

        break; 

      
      case 1976 : 
      case 3951 :

        text("Si", x, y+50);

        break;
      }
    }
  }
}